==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/modules/options/optw_ircview.h <==
#ifndef _OPTW_IRCVIEW_H_
#define _OPTW_IRCVIEW_H_

//
//   File : optw_ircview.h
//   Creation date : Sat Aug 11 2001 03:28:19 CEST by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_optionswidget.h"

#define KVI_OPTIONS_WIDGET_ICON_KviIrcViewLookOptionsWidget KVI_SMALLICON_IRCVIEW
#define KVI_OPTIONS_WIDGET_NAME_KviIrcViewLookOptionsWidget __tr_no_lookup("Output")
#define KVI_OPTIONS_WIDGET_PARENT_KviIrcViewLookOptionsWidget KviThemeOptionsWidget


class KviIrcViewLookOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviIrcViewLookOptionsWidget(QWidget * parent);
	~KviIrcViewLookOptionsWidget();
};

#define KVI_OPTIONS_WIDGET_ICON_KviIrcViewFeaturesOptionsWidget KVI_SMALLICON_IRCVIEW
#define KVI_OPTIONS_WIDGET_NAME_KviIrcViewFeaturesOptionsWidget __tr_no_lookup("Output")
#define KVI_OPTIONS_WIDGET_PARENT_KviIrcViewFeaturesOptionsWidget KviInterfaceFeaturesOptionsWidget

class KviIrcViewFeaturesOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviIrcViewFeaturesOptionsWidget(QWidget * parent);
	~KviIrcViewFeaturesOptionsWidget();
};

#endif //!_OPTW_IRCVIEW_H_

==> kvirc_3.2.4.orig.tar.gz: kvirc-3.2.4/src/modules/options/optw_ircview.h <==
#ifndef _OPTW_IRCVIEW_H_
#define _OPTW_IRCVIEW_H_

//
//   File : optw_ircview.h
//   Creation date : Sat Aug 11 2001 03:28:19 CEST by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2001 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_optionswidget.h"
#include <qcombobox.h>


#define KVI_OPTIONS_WIDGET_ICON_KviIrcViewLookOptionsWidget KVI_SMALLICON_IRCVIEW
#define KVI_OPTIONS_WIDGET_NAME_KviIrcViewLookOptionsWidget __tr2qs_no_lookup("Output")
#define KVI_OPTIONS_WIDGET_KEYWORDS_KviIrcViewLookOptionsWidget __tr2qs_no_lookup("theme,colors,output")
#define KVI_OPTIONS_WIDGET_GROUP_KviIrcViewLookOptionsWidget "theme"

class KviIrcViewLookOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
private:
	QComboBox* m_pHorisontalAlign;
	QComboBox* m_pVerticalAlign;
public:
	KviIrcViewLookOptionsWidget(QWidget * parent);
	~KviIrcViewLookOptionsWidget();
	
	virtual void commit();
};

#define KVI_OPTIONS_WIDGET_ICON_KviIrcViewFeaturesOptionsWidget KVI_SMALLICON_IRCVIEW
#define KVI_OPTIONS_WIDGET_NAME_KviIrcViewFeaturesOptionsWidget __tr2qs_no_lookup("Output")
#define KVI_OPTIONS_WIDGET_PARENT_KviIrcViewFeaturesOptionsWidget KviInterfaceFeaturesOptionsWidget
#define KVI_OPTIONS_WIDGET_MINIMAL_USER_EXPERIENCE_LEVEL_KviIrcViewFeaturesOptionsWidget 2

class KviIrcViewFeaturesOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviIrcViewFeaturesOptionsWidget(QWidget * parent);
	~KviIrcViewFeaturesOptionsWidget();
public:
	KviBoolSelector * m_pUseTimestampSelector;
	KviBoolSelector * m_pSpecialTimestampColorSelector;
	KviMircTextColorSelector * m_pTimestampColorSelector;
protected slots:
	void enableDisableTimestampSelector(bool);
};

#endif //!_OPTW_IRCVIEW_H_
